@@ -80,7 +80,7 @@ fast_dummy_factor <- function(x) {
 }
 
 fast_factor <- function(x, levels=NULL) {
-  if (!methods::is(x, 'factor')) {
+  if (!is.factor(x)) {
     if (!all(is.na(x))) {
       if (is.null(levels)) levels = vector('character', 0)
       x = fast_factor_cpp(as.character(x), as.character(levels))
